# cosasi (COntagion Simulation And Source Inference)

``cosasi`` is a Python package for graph diffusion source localization, allowing users to:

- **perform and evaluate** source inference using standard techniques from literature,
- **contribute** innovative localization methods to a growing core library, and
- **benchmark** new techniques against a battery of comparable schemes.


## Table of Contents
* [Table of Contents](#table-of-contents)
* [Contact](#contact)
* [License](#license)




## Contact

Questions? Reach out:
- Lucas ([email](mailto:lmccabe@lmi.org))


## License
[MIT](https://choosealicense.com/licenses/mit/)
